import sqlite3
import pathlib
import threading
# from sqlite3 import Connection, Cursor


class EventBacklogProcessor:
	_version: ''
	# _cursor: Cursor
	# _conn: Connection

	def __init__(self, version):
		self._thread_data = threading.local()
		self._version = version
		sqlite3.connect(
			pathlib.Path(__file__).parent.absolute().joinpath("pic.{}.db".format(version))
		).cursor(

		).execute(
			"""CREATE TABLE IF NOT EXISTS backlog
			(
			id INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE,
			event TEXT NOT NULL,
			data TEXT NOT NULL,
			timestamp TIMESTAMP DEFAULT (strftime('%s', 'now')) NOT NULL
			);"""
		).close()

	def init_db(self, version):
		if hasattr(self._thread_data, 'conn'):
			return
		self._thread_data.conn = sqlite3.connect(
			pathlib.Path(__file__).parent.absolute().joinpath("pic.{}.db".format(version))
		)
		self._thread_data.cursor = self._thread_data.conn.cursor()

	def insert(self, event, data):
		self.init_db(self._version)
		self._thread_data.cursor.execute("INSERT INTO backlog (event, data) VALUES (?, ?)", (event, data))
		self._thread_data.conn.commit()

	def next(self):
		self.init_db(self._version)
		return self._thread_data.cursor.execute(
			"SELECT t.id, t.event, t.data, t.timestamp FROM backlog t ORDER BY id LIMIT 1"
		).fetchone() or (0, '', '')

	def count(self):
		self.init_db(self._version)
		return (self._thread_data.cursor.execute("SELECT COUNT() as cnt FROM backlog t;").fetchone() or (0))[0]

	def rm(self, row_id):
		self.init_db(self._version)
		self._thread_data.cursor.execute("DELETE FROM backlog WHERE id = ?", [(row_id)])
		self._thread_data.conn.commit()
